@@ -10,18 +10,22 @@ test_that("Non Cross-Validated Functions Work", {
   pavlist <- PAV(T,That,Y)
   papdlist <- PAPD(T,That,That2,Y,0.5)
   aupeclist <- AUPEC(T,tau,Y)
+  gatelist <- GATE(T,tau,Y,ngates=2)
   expect_type(papelist,"list")
   expect_type(pavlist,"list")
   expect_type(papdlist,"list")
   expect_type(aupeclist,"list")
+  expect_type(gatelist,"list")
   expect_type(papelist$pape,"double")
   expect_type(pavlist$pav,"double")
   expect_type(papdlist$papd,"double")
   expect_type(aupeclist$aupec,"double")
+  expect_type(gatelist$gate,"double")
   expect_type(papelist$sd,"double")
   expect_type(pavlist$sd,"double")
   expect_type(papdlist$sd,"double")
   expect_type(aupeclist$sd,"double")
+  expect_type(gatelist$sd,"double")
 })
 
 test_that("Cross-Validated Functions Work", {
@@ -35,17 +39,21 @@ test_that("Cross-Validated Functions Work", {
   pavlist <- PAVcv(T,That,Y,ind)
   papdlist <- PAPDcv(T,That,That2,Y,ind,plim = 0.5)
   aupeclist <- AUPECcv(T,tau,Y,ind)
+  gatelist <- GATEcv(T,tau,Y,ind,ngates=2)
   expect_type(papelist,"list")
   expect_type(pavlist,"list")
   expect_type(papdlist,"list")
   expect_type(aupeclist,"list")
+  expect_type(gatelist,"list")
   expect_type(papelist$pape,"double")
   expect_type(pavlist$pav,"double")
   expect_type(papdlist$papd,"double")
   expect_type(aupeclist$aupec,"double")
+  expect_type(gatelist$gate,"double")
   expect_type(papelist$sd,"double")
   expect_type(pavlist$sd,"double")
   expect_type(papdlist$sd,"double")
   expect_type(aupeclist$sd,"double")
+  expect_type(gatelist$sd,"double")
 })
 
